@@ -4,6 +4,7 @@ from django.db.models.signals import pre_save
 from django.db import DatabaseError
 
 from bleach import clean 
+from html5lib import html5parser
 from janitor import whitelists
 
 def _register(callback, content_type_list):
@@ -95,6 +96,34 @@ def _clean_class_objects(klass_list):
     
     return object_count
 
+def _get_tags_used_in_content(app_label=None, model=None):
+    """
+    Use html5lib's parser to get a list of HTML tags used in content
+    associated with a FieldSanitizer.
+
+    This can be useful when determining what to include in a whitelist,
+    and is used in the ``list_html_elements`` and ``list_html_elements_for_model``
+    management commands.
+
+    """
+    queryset = FieldSanitizer.objects.all()
+    if app_label and model:
+        queryset = queryset.filter(content_type__app_label=app_label, content_type__model=model)
+
+    tag_list = []
+
+    for fs in queryset:
+        model_class = fs.content_type.model_class()
+        content_list = model_class.objects.values_list(fs.field_name, flat=True)
+
+        for content in content_list:
+            doc = html5parser.parse(content)
+            tag_list.extend([str(tag.name) for tag in doc if tag.name])
+
+    tag_list = list(set(tag_list)) # remove duplicates
+    tag_list.sort()
+    return tag_list
+
 try:
     # Register everything 
     _content_type_ids = FieldSanitizer.objects.values_list('content_type').distinct()
